@@ -187,7 +187,7 @@ def test_function_with_only_description():
 
   tool = convert_function_to_tool(only_description).model_dump()
   assert tool['function']['description'] == 'A function with only a description.'
-  assert tool['function']['parameters'] == {'type': 'object', 'properties': {}, 'required': None}
+  assert tool['function']['parameters'] == {'type': 'object', 'defs': None, 'items': None, 'required': None, 'properties': {}}
 
   def only_description_with_args(x: int, y: int):
     """
@@ -199,9 +199,11 @@ def test_function_with_only_description():
   assert tool['function']['description'] == 'A function with only a description.'
   assert tool['function']['parameters'] == {
     'type': 'object',
+    'defs': None,
+    'items': None,
     'properties': {
-      'x': {'type': 'integer', 'description': ''},
-      'y': {'type': 'integer', 'description': ''},
+      'x': {'type': 'integer', 'description': '', 'enum': None, 'items': None},
+      'y': {'type': 'integer', 'description': '', 'enum': None, 'items': None},
     },
     'required': ['x', 'y'],
   }
